==> api-0.16.0-sources.jar: io/strimzi/api/kafka/model/listener/KafkaListenerExternalRouteFluent.java <==
package io.strimzi.api.kafka.model.listener;

import io.fabric8.kubernetes.api.model.networking.NetworkPolicyPeer;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;

public interface KafkaListenerExternalRouteFluent<A extends KafkaListenerExternalRouteFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAuth instead.
 * @return The buildable object.
 */
@Deprecated public KafkaListenerAuthentication getAuth();
    public KafkaListenerAuthentication buildAuth();
    public A withAuth(KafkaListenerAuthentication auth);
    public Boolean hasAuth();
    public A withKafkaListenerAuthenticationOAuth(KafkaListenerAuthenticationOAuth kafkaListenerAuthenticationOAuth);
    public KafkaListenerExternalRouteFluent.KafkaListenerAuthenticationOAuthNested<A> withNewKafkaListenerAuthenticationOAuth();
    public KafkaListenerExternalRouteFluent.KafkaListenerAuthenticationOAuthNested<A> withNewKafkaListenerAuthenticationOAuthLike(KafkaListenerAuthenticationOAuth item);
    public A withKafkaListenerAuthenticationTlsAuth(KafkaListenerAuthenticationTls kafkaListenerAuthenticationTlsAuth);
    public KafkaListenerExternalRouteFluent.KafkaListenerAuthenticationTlsAuthNested<A> withNewKafkaListenerAuthenticationTlsAuth();
    public KafkaListenerExternalRouteFluent.KafkaListenerAuthenticationTlsAuthNested<A> withNewKafkaListenerAuthenticationTlsAuthLike(KafkaListenerAuthenticationTls item);
    public A withKafkaListenerAuthenticationScramSha512Auth(KafkaListenerAuthenticationScramSha512 kafkaListenerAuthenticationScramSha512Auth);
    public KafkaListenerExternalRouteFluent.KafkaListenerAuthenticationScramSha512AuthNested<A> withNewKafkaListenerAuthenticationScramSha512Auth();
    public KafkaListenerExternalRouteFluent.KafkaListenerAuthenticationScramSha512AuthNested<A> withNewKafkaListenerAuthenticationScramSha512AuthLike(KafkaListenerAuthenticationScramSha512 item);
    public A addToNetworkPolicyPeers(int index,NetworkPolicyPeer item);
    public A setToNetworkPolicyPeers(int index,NetworkPolicyPeer item);
    public A addToNetworkPolicyPeers(NetworkPolicyPeer... items);
    public A addAllToNetworkPolicyPeers(Collection<NetworkPolicyPeer> items);
    public A removeFromNetworkPolicyPeers(NetworkPolicyPeer... items);
    public A removeAllFromNetworkPolicyPeers(Collection<NetworkPolicyPeer> items);
    public List<NetworkPolicyPeer> getNetworkPolicyPeers();
    public NetworkPolicyPeer getNetworkPolicyPeer(int index);
    public NetworkPolicyPeer getFirstNetworkPolicyPeer();
    public NetworkPolicyPeer getLastNetworkPolicyPeer();
    public NetworkPolicyPeer getMatchingNetworkPolicyPeer(io.fabric8.kubernetes.api.builder.Predicate<NetworkPolicyPeer> predicate);
    public Boolean hasMatchingNetworkPolicyPeer(io.fabric8.kubernetes.api.builder.Predicate<NetworkPolicyPeer> predicate);
    public A withNetworkPolicyPeers(List<NetworkPolicyPeer> networkPolicyPeers);
    public A withNetworkPolicyPeers(NetworkPolicyPeer... networkPolicyPeers);
    public Boolean hasNetworkPolicyPeers();
    
/**
 * This method has been deprecated, please use method buildOverrides instead.
 * @return The buildable object.
 */
@Deprecated public RouteListenerOverride getOverrides();
    public RouteListenerOverride buildOverrides();
    public A withOverrides(RouteListenerOverride overrides);
    public Boolean hasOverrides();
    public KafkaListenerExternalRouteFluent.OverridesNested<A> withNewOverrides();
    public KafkaListenerExternalRouteFluent.OverridesNested<A> withNewOverridesLike(RouteListenerOverride item);
    public KafkaListenerExternalRouteFluent.OverridesNested<A> editOverrides();
    public KafkaListenerExternalRouteFluent.OverridesNested<A> editOrNewOverrides();
    public KafkaListenerExternalRouteFluent.OverridesNested<A> editOrNewOverridesLike(RouteListenerOverride item);
    
/**
 * This method has been deprecated, please use method buildConfiguration instead.
 * @return The buildable object.
 */
@Deprecated public KafkaListenerExternalConfiguration getConfiguration();
    public KafkaListenerExternalConfiguration buildConfiguration();
    public A withConfiguration(KafkaListenerExternalConfiguration configuration);
    public Boolean hasConfiguration();
    public KafkaListenerExternalRouteFluent.ConfigurationNested<A> withNewConfiguration();
    public KafkaListenerExternalRouteFluent.ConfigurationNested<A> withNewConfigurationLike(KafkaListenerExternalConfiguration item);
    public KafkaListenerExternalRouteFluent.ConfigurationNested<A> editConfiguration();
    public KafkaListenerExternalRouteFluent.ConfigurationNested<A> editOrNewConfiguration();
    public KafkaListenerExternalRouteFluent.ConfigurationNested<A> editOrNewConfigurationLike(KafkaListenerExternalConfiguration item);

    public interface KafkaListenerAuthenticationOAuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaListenerAuthenticationOAuthFluent<KafkaListenerExternalRouteFluent.KafkaListenerAuthenticationOAuthNested<N>>{

        
    public N and();    public N endKafkaListenerAuthenticationOAuth();
}
    public interface KafkaListenerAuthenticationTlsAuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaListenerAuthenticationTlsFluent<KafkaListenerExternalRouteFluent.KafkaListenerAuthenticationTlsAuthNested<N>>{

        
    public N and();    public N endKafkaListenerAuthenticationTlsAuth();
}
    public interface KafkaListenerAuthenticationScramSha512AuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaListenerAuthenticationScramSha512Fluent<KafkaListenerExternalRouteFluent.KafkaListenerAuthenticationScramSha512AuthNested<N>>{

        
    public N and();    public N endKafkaListenerAuthenticationScramSha512Auth();
}
    public interface OverridesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RouteListenerOverrideFluent<KafkaListenerExternalRouteFluent.OverridesNested<N>>{

        
    public N and();    public N endOverrides();
}
    public interface ConfigurationNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaListenerExternalConfigurationFluent<KafkaListenerExternalRouteFluent.ConfigurationNested<N>>{

        
    public N and();    public N endConfiguration();
}


}

==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/listener/KafkaListenerExternalRouteFluent.java <==
package io.strimzi.api.kafka.model.listener;

import io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeer;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;

public interface KafkaListenerExternalRouteFluent<A extends KafkaListenerExternalRouteFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAuth instead.
 * @return The buildable object.
 */
@Deprecated public KafkaListenerAuthentication getAuth();
    public KafkaListenerAuthentication buildAuth();
    public A withAuth(KafkaListenerAuthentication auth);
    public Boolean hasAuth();
    public A withKafkaListenerAuthenticationOAuth(KafkaListenerAuthenticationOAuth kafkaListenerAuthenticationOAuth);
    public KafkaListenerExternalRouteFluent.KafkaListenerAuthenticationOAuthNested<A> withNewKafkaListenerAuthenticationOAuth();
    public KafkaListenerExternalRouteFluent.KafkaListenerAuthenticationOAuthNested<A> withNewKafkaListenerAuthenticationOAuthLike(KafkaListenerAuthenticationOAuth item);
    public A withKafkaListenerAuthenticationTlsAuth(KafkaListenerAuthenticationTls kafkaListenerAuthenticationTlsAuth);
    public KafkaListenerExternalRouteFluent.KafkaListenerAuthenticationTlsAuthNested<A> withNewKafkaListenerAuthenticationTlsAuth();
    public KafkaListenerExternalRouteFluent.KafkaListenerAuthenticationTlsAuthNested<A> withNewKafkaListenerAuthenticationTlsAuthLike(KafkaListenerAuthenticationTls item);
    public A withKafkaListenerAuthenticationScramSha512Auth(KafkaListenerAuthenticationScramSha512 kafkaListenerAuthenticationScramSha512Auth);
    public KafkaListenerExternalRouteFluent.KafkaListenerAuthenticationScramSha512AuthNested<A> withNewKafkaListenerAuthenticationScramSha512Auth();
    public KafkaListenerExternalRouteFluent.KafkaListenerAuthenticationScramSha512AuthNested<A> withNewKafkaListenerAuthenticationScramSha512AuthLike(KafkaListenerAuthenticationScramSha512 item);
    public A addToNetworkPolicyPeers(int index,NetworkPolicyPeer item);
    public A setToNetworkPolicyPeers(int index,NetworkPolicyPeer item);
    public A addToNetworkPolicyPeers(NetworkPolicyPeer... items);
    public A addAllToNetworkPolicyPeers(Collection<NetworkPolicyPeer> items);
    public A removeFromNetworkPolicyPeers(NetworkPolicyPeer... items);
    public A removeAllFromNetworkPolicyPeers(Collection<NetworkPolicyPeer> items);
    public java.util.List<NetworkPolicyPeer> getNetworkPolicyPeers();
    public NetworkPolicyPeer getNetworkPolicyPeer(int index);
    public NetworkPolicyPeer getFirstNetworkPolicyPeer();
    public NetworkPolicyPeer getLastNetworkPolicyPeer();
    public NetworkPolicyPeer getMatchingNetworkPolicyPeer(io.fabric8.kubernetes.api.builder.Predicate<NetworkPolicyPeer> predicate);
    public Boolean hasMatchingNetworkPolicyPeer(io.fabric8.kubernetes.api.builder.Predicate<NetworkPolicyPeer> predicate);
    public A withNetworkPolicyPeers(java.util.List<NetworkPolicyPeer> networkPolicyPeers);
    public A withNetworkPolicyPeers(NetworkPolicyPeer... networkPolicyPeers);
    public Boolean hasNetworkPolicyPeers();
    
/**
 * This method has been deprecated, please use method buildOverrides instead.
 * @return The buildable object.
 */
@Deprecated public RouteListenerOverride getOverrides();
    public RouteListenerOverride buildOverrides();
    public A withOverrides(RouteListenerOverride overrides);
    public Boolean hasOverrides();
    public KafkaListenerExternalRouteFluent.OverridesNested<A> withNewOverrides();
    public KafkaListenerExternalRouteFluent.OverridesNested<A> withNewOverridesLike(RouteListenerOverride item);
    public KafkaListenerExternalRouteFluent.OverridesNested<A> editOverrides();
    public KafkaListenerExternalRouteFluent.OverridesNested<A> editOrNewOverrides();
    public KafkaListenerExternalRouteFluent.OverridesNested<A> editOrNewOverridesLike(RouteListenerOverride item);
    
/**
 * This method has been deprecated, please use method buildConfiguration instead.
 * @return The buildable object.
 */
@Deprecated public KafkaListenerExternalConfiguration getConfiguration();
    public KafkaListenerExternalConfiguration buildConfiguration();
    public A withConfiguration(KafkaListenerExternalConfiguration configuration);
    public Boolean hasConfiguration();
    public KafkaListenerExternalRouteFluent.ConfigurationNested<A> withNewConfiguration();
    public KafkaListenerExternalRouteFluent.ConfigurationNested<A> withNewConfigurationLike(KafkaListenerExternalConfiguration item);
    public KafkaListenerExternalRouteFluent.ConfigurationNested<A> editConfiguration();
    public KafkaListenerExternalRouteFluent.ConfigurationNested<A> editOrNewConfiguration();
    public KafkaListenerExternalRouteFluent.ConfigurationNested<A> editOrNewConfigurationLike(KafkaListenerExternalConfiguration item);

    public interface KafkaListenerAuthenticationOAuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaListenerAuthenticationOAuthFluent<KafkaListenerExternalRouteFluent.KafkaListenerAuthenticationOAuthNested<N>>{

        
    public N and();    public N endKafkaListenerAuthenticationOAuth();
}
    public interface KafkaListenerAuthenticationTlsAuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaListenerAuthenticationTlsFluent<KafkaListenerExternalRouteFluent.KafkaListenerAuthenticationTlsAuthNested<N>>{

        
    public N and();    public N endKafkaListenerAuthenticationTlsAuth();
}
    public interface KafkaListenerAuthenticationScramSha512AuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaListenerAuthenticationScramSha512Fluent<KafkaListenerExternalRouteFluent.KafkaListenerAuthenticationScramSha512AuthNested<N>>{

        
    public N and();    public N endKafkaListenerAuthenticationScramSha512Auth();
}
    public interface OverridesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RouteListenerOverrideFluent<KafkaListenerExternalRouteFluent.OverridesNested<N>>{

        
    public N and();    public N endOverrides();
}
    public interface ConfigurationNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaListenerExternalConfigurationFluent<KafkaListenerExternalRouteFluent.ConfigurationNested<N>>{

        
    public N and();    public N endConfiguration();
}


}
